@@ -12,21 +12,9 @@
 #'
 
 (function() {
-  # prior to starting app, close open connections
-  closeAllConnections()
-
-  # library calls
-  env.init <- envir.prep()
-
-  # load required
-  load(file = file.path(env.init,"req_pack.ob"))
-
-
-  # declare viewer
-  shiny::paneViewer(500) -> viewer
 
   # run the app
-  shiny::runGadget(.symbol.equation.gpt.ui, .symbol.equation.gpt.server, viewer = viewer)
+  equationSymbol.Widget(viewer = "pane")
 
 
 }) -> symbol.equation.ui
@@ -46,6 +34,34 @@
 #'
 
 (function() {
+
+  # run the app
+  equationSymbol.Widget(viewer = "dialog")
+
+
+}) -> symbol.equation.ui2
+
+
+#' Primary widget container
+#'
+#' Customizable widget opener
+#'
+#' @param viewer viewer option to open widget
+#'
+#' @return shiny app widget
+#'
+#' @examples
+#' if(interactive()){
+#' equationSymbol.Widget()
+#' }
+#'
+#' @export
+#'
+
+(function(viewer = c("pane","dialog")) {
+  # get viewer option
+  match.arg(viewer) -> viewer
+
   # prior to starting app, close open connections
   closeAllConnections()
 
@@ -56,12 +72,18 @@
   load(file = file.path(env.init,"req_pack.ob"))
 
   # declare viewer
-  shiny::dialogViewer(dialogName = "Symbols and Equations Builder",
+  if(viewer == "dialog"){
+    shiny::dialogViewer(dialogName = "Symbols and Equations Builder",
                       width = 850,
                       height = 750) -> viewer
+  }else{
+    shiny::paneViewer(700) -> viewer
+  }
+
 
   # run the app
   shiny::runGadget(.symbol.equation.gpt.ui, .symbol.equation.gpt.server, viewer = viewer)
 
 
-}) -> symbol.equation.ui2
+}) -> equationSymbol.Widget
+
